package com.uas.cloud.oauth2.provider;

import com.uas.cloud.oauth2.core.SaltedUser;
import com.uas.cloud.oauth2.entity.UserAccount;
import com.uas.cloud.oauth2.entity.UserCredential;
import com.uas.cloud.oauth2.repository.UserAccountRepository;
import com.uas.cloud.oauth2.repository.UserCredentialRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.time.ZonedDateTime;
import java.util.Collections;

/**
 * Created by Pro1 on 2017/3/22.
 */
@Component
public class JpaUserDetailsService implements UserDetailsService {

    private final UserCredentialRepository userCredentialRepository;
    private final UserAccountRepository userAccountRepository;

    @Autowired
    public JpaUserDetailsService(UserCredentialRepository userCredentialRepository, UserAccountRepository userAccountRepository) {
        this.userCredentialRepository = userCredentialRepository;
        this.userAccountRepository = userAccountRepository;
    }

    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        UserCredential credential = userCredentialRepository.findOneByUserKey(username);
        UserAccount account = userAccountRepository.findOne(credential.getAccountId());
        LocalDateTime utcNow = ZonedDateTime.now(ZoneOffset.UTC).toLocalDateTime();
        return new SaltedUser(
                credential.getUserKey(),
                credential.getSecretCode(),
                !account.isDisabled(),
                !account.getExpiresAt().isBefore(utcNow),
                !credential.getExpiresAt().isBefore(utcNow),
                !account.isLocked(),
                Collections.<GrantedAuthority>emptyList(),
                credential.getSalt()
        );
    }
}
